==> directfb_1.2.10.0.orig.tar.gz: DirectFB-1.2.10/gfxdrivers/vmware/vmware_gfxdriver.h <==
/*
   (c) Copyright 2001-2008  The world wide DirectFB Open Source Community (directfb.org)
   (c) Copyright 2000-2004  Convergence (integrated media) GmbH

   All rights reserved.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __VMWARE_GFXDRIVER_H__
#define __VMWARE_GFXDRIVER_H__

#ifndef FB_ACCEL_VMWARE_BLITTER
#define FB_ACCEL_VMWARE_BLITTER 51
#endif


typedef struct {
     /* validation flags */
     int                    v_flags;

     /* cached/computed values */
     void                  *dst_addr;
     unsigned long          dst_pitch;
     DFBSurfacePixelFormat  dst_format;
     unsigned long          dst_bpp;

     void                  *src_addr;
     unsigned long          src_pitch;
     DFBSurfacePixelFormat  src_format;
     unsigned long          src_bpp;

     unsigned long          color_pixel;

     /** Add shared data here... **/
} VMWareDeviceData;


typedef struct {

     /** Add local data here... **/
} VMWareDriverData;


#endif

==> directfb_1.7.7.orig.tar.gz: DirectFB-1.7.7/gfxdrivers/vmware/vmware_gfxdriver.h <==
/*
   (c) Copyright 2012-2013  DirectFB integrated media GmbH
   (c) Copyright 2001-2013  The world wide DirectFB Open Source Community (directfb.org)
   (c) Copyright 2000-2004  Convergence (integrated media) GmbH

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Shimokawa <andi@directfb.org>,
              Marek Pikarski <mass@directfb.org>,
              Sven Neumann <neo@directfb.org>,
              Ville Syrjälä <syrjala@sci.fi> and
              Claudio Ciccani <klan@users.sf.net>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __VMWARE_GFXDRIVER_H__
#define __VMWARE_GFXDRIVER_H__

#ifndef FB_ACCEL_VMWARE_BLITTER
#define FB_ACCEL_VMWARE_BLITTER 51
#endif


typedef struct {
     /* validation flags */
     int                    v_flags;

     /* cached/computed values */
     void                  *dst_addr;
     unsigned long          dst_pitch;
     DFBSurfacePixelFormat  dst_format;
     unsigned long          dst_bpp;

     void                  *src_addr;
     unsigned long          src_pitch;
     DFBSurfacePixelFormat  src_format;
     unsigned long          src_bpp;

     unsigned long          color_pixel;

     /** Add shared data here... **/
} VMWareDeviceData;


typedef struct {
     DirectProcessor        processor;
     unsigned int           packet_count;

     DirectMutex            wait_lock;
     DirectWaitQueue        wait_queue;
     
     CoreGraphicsSerial     last;
     CoreGraphicsSerial     next;
     CoreGraphicsSerial     done;

     /** Add local data here... **/
} VMWareDriverData;


#endif
